package com.fastbee.data.controller.userRecharge;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.fastbee.common.annotation.Log;
import com.fastbee.common.core.controller.BaseController;
import com.fastbee.common.core.domain.AjaxResult;
import com.fastbee.common.enums.BusinessType;
import com.fastbee.rechargecard.domain.NgUserRechargeRecords;
import com.fastbee.rechargecard.service.INgUserRechargeRecordsService;
import com.fastbee.common.utils.poi.ExcelUtil;
import com.fastbee.common.core.page.TableDataInfo;

/**
 * 用户充值记录Controller
 *
 * @author kerwincui
 * @date 2024-12-19
 */
@RestController
@RequestMapping("/rechargecard/records")
@Api(tags = "用户充值记录")
public class NgUserRechargeRecordsController extends BaseController
{
    @Autowired
    private INgUserRechargeRecordsService ngUserRechargeRecordsService;

    /**
     * 查询用户充值记录列表
     */
//    @PreAuthorize("@ss.hasPermi('rechargecard:records:list')")
    @GetMapping("/list")
    @ApiOperation("查询用户充值记录列表")
    public TableDataInfo list(NgUserRechargeRecords ngUserRechargeRecords)
    {
        startPage();
        List<NgUserRechargeRecords> list = ngUserRechargeRecordsService.selectNgUserRechargeRecordsList(ngUserRechargeRecords);
        return getDataTable(list);
    }

    /**
     * 导出用户充值记录列表
     */
    @ApiOperation("导出用户充值记录列表")
//    @PreAuthorize("@ss.hasPermi('rechargecard:records:export')")
    @PostMapping("/export")
    public void export(HttpServletResponse response, NgUserRechargeRecords ngUserRechargeRecords)
    {
        List<NgUserRechargeRecords> list = ngUserRechargeRecordsService.selectNgUserRechargeRecordsList(ngUserRechargeRecords);
        ExcelUtil<NgUserRechargeRecords> util = new ExcelUtil<NgUserRechargeRecords>(NgUserRechargeRecords.class);
        util.exportExcel(response, list, "用户充值记录数据");
    }

    /**
     * 获取用户充值记录详细信息
     */
//    @PreAuthorize("@ss.hasPermi('rechargecard:records:query')")
    @GetMapping(value = "/{userId}")
    @ApiOperation("获取用户充值记录详细信息")
    public AjaxResult getInfo(@PathVariable("userId") Long userId)
    {
        return success(ngUserRechargeRecordsService.selectNgUserRechargeRecordsById(userId));
    }

    /**
     * 新增用户充值记录
     */
//    @PreAuthorize("@ss.hasPermi('rechargecard:records:add')")
    @PostMapping
    @ApiOperation("新增用户充值记录")
    public AjaxResult add(@RequestBody NgUserRechargeRecords ngUserRechargeRecords)
    {
        return toAjax(ngUserRechargeRecordsService.insertNgUserRechargeRecords(ngUserRechargeRecords));
    }

    /**
     * 修改用户充值记录
     */
//    @PreAuthorize("@ss.hasPermi('rechargecard:records:edit')")
    @PutMapping
    @ApiOperation("修改用户充值记录")
    public AjaxResult edit(@RequestBody NgUserRechargeRecords ngUserRechargeRecords)
    {
        return toAjax(ngUserRechargeRecordsService.updateNgUserRechargeRecords(ngUserRechargeRecords));
    }

    /**
     * 删除用户充值记录
     */
//    @PreAuthorize("@ss.hasPermi('rechargecard:records:remove')")
    @DeleteMapping("/{ids}")
    @ApiOperation("删除用户充值记录")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(ngUserRechargeRecordsService.deleteNgUserRechargeRecordsByIds(ids));
    }
}
