package com.fastbee.rechargecard.service.impl;

import java.util.List;
import com.fastbee.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fastbee.rechargecard.mapper.NgUserRechargeRecordsMapper;
import com.fastbee.rechargecard.domain.NgUserRechargeRecords;
import com.fastbee.rechargecard.service.INgUserRechargeRecordsService;

/**
 * 用户充值记录Service业务层处理
 *
 * @author kerwincui
 * @date 2024-12-19
 */
@Service
public class NgUserRechargeRecordsServiceImpl implements INgUserRechargeRecordsService
{
    @Autowired
    private NgUserRechargeRecordsMapper ngUserRechargeRecordsMapper;

    /**
     * 查询用户充值记录
     *
     * @param userId 用户id
     * @return 用户充值记录
     */
    @Override
    public NgUserRechargeRecords selectNgUserRechargeRecordsById(Long userId)
    {
        return ngUserRechargeRecordsMapper.selectNgUserRechargeRecordsById(userId);
    }

    /**
     * 查询用户充值记录列表
     *
     * @param ngUserRechargeRecords 用户充值记录
     * @return 用户充值记录
     */
    @Override
    public List<NgUserRechargeRecords> selectNgUserRechargeRecordsList(NgUserRechargeRecords ngUserRechargeRecords)
    {
        return ngUserRechargeRecordsMapper.selectNgUserRechargeRecordsList(ngUserRechargeRecords);
    }

    /**
     * 新增用户充值记录
     *
     * @param ngUserRechargeRecords 用户充值记录
     * @return 结果
     */
    @Override
    public int insertNgUserRechargeRecords(NgUserRechargeRecords ngUserRechargeRecords)
    {
        ngUserRechargeRecords.setCreateTime(DateUtils.getNowDate());
        ngUserRechargeRecordsMapper.insertNgUserRechargeRecords(ngUserRechargeRecords);

        return ngUserRechargeRecordsMapper.insertNgUserRechargeRecords(ngUserRechargeRecords);
    }

    /**
     * 修改用户充值记录
     *
     * @param ngUserRechargeRecords 用户充值记录
     * @return 结果
     */
    @Override
    public int updateNgUserRechargeRecords(NgUserRechargeRecords ngUserRechargeRecords)
    {
        ngUserRechargeRecords.setUpdateTime(DateUtils.getNowDate());
        return ngUserRechargeRecordsMapper.updateNgUserRechargeRecords(ngUserRechargeRecords);
    }

    /**
     * 批量删除用户充值记录
     *
     * @param ids 需要删除的用户充值记录主键
     * @return 结果
     */
    @Override
    public int deleteNgUserRechargeRecordsByIds(Long[] ids)
    {
        return ngUserRechargeRecordsMapper.deleteNgUserRechargeRecordsByIds(ids);
    }

    /**
     * 删除用户充值记录信息
     *
     * @param id 用户充值记录主键
     * @return 结果
     */
    @Override
    public int deleteNgUserRechargeRecordsById(Long id)
    {
        return ngUserRechargeRecordsMapper.deleteNgUserRechargeRecordsById(id);
    }
}
